﻿// 1. 导入依赖模块
const express = require('express');
const RPCClient = require('@alicloud/pop-core');
const path = require('path');
const cors = require('cors');

// 2. 获取环境变量
const WIFE_CODE = process.env.WIFE_CODE;
const GUEST_CODE = process.env.GUEST_CODE;

// 3. 检查环境变量是否设置
if (!WIFE_CODE || !GUEST_CODE) {
  console.error('错误：环境变量 WIFE_CODE 和 GUEST_CODE 必须设置');
  process.exit(1);
}

// 4. 初始化阿里云客户端
const client = new RPCClient({
  accessKeyId: process.env.ACCESS_KEY_ID,
  accessKeySecret: process.env.ACCESS_KEY_SECRET,
  endpoint: 'https://dm.aliyuncs.com',
  apiVersion: '2015-11-23'
});

// 5. 创建 Express 应用
const app = express();

// 6. 配置中间件
const corsOptions = {
  origin: 'https://m.axiaoke.cn',
  methods: ['GET', 'POST'],
  allowedHeaders: ['Content-Type'],
  maxAge: 86400
};

app.use(cors(corsOptions));
app.use(express.json({ limit: '10kb' }));

// 7. 定义业务路由
app.post('/submit-order', async (req, res) => {
  const { confirmCode, isNoCookingToday, selectedItems, mealDate, mealTime, note, activities = [] } = req.body;

  // 8 确认码规则配置
  const CODE_RULES = {
        [WIFE_CODE]: { // 请替换为实际的确认码
            role: '老婆',
            subjectPrefix: '婷婷',
            bodyTemplateNormal: (count, mealInfo, items, note) => 
                `葛先生，您好：\n\n` +
                `您老婆已经点餐${count}道菜品，请于${mealInfo}备好，具体菜名如下：\n\n` +
                `${items}\n` +
                `${note ? `\n她说：${note}\n` : ''}` +
                `\n请及时准备！`,
            bodyTemplateNoCooking: (activities, note) => {
                const activitiesText = Array.isArray(activities) && activities.length > 0 ? activities.join('、') : '其他';
                return `葛先生，您好：\n\n` +
                       `您老婆说：今天不用做饭，她建议您可以选择${activitiesText}。\n` +
                       `${note ? `\n她还说：${note}\n` : ''}` +
                       `\n请知悉。`;
      }
    }, // 添加逗号
    [GUEST_CODE]: {
      role: '客人',
      subjectPrefix: '客人',
      bodyTemplateNormal: (count, mealInfo, items, note) => 
        `葛先生，您好：\n\n` +
        `客人已经点餐${count}道菜品，请于${mealInfo}备好，具体菜名如下：\n\n` +
        `${items}\n` +
        `${note ? `\n客人还说：${note}\n` : ''}` +
        `\n请及时准备！`
    }
  };

  // 9 验证确认码
  const rule = CODE_RULES[confirmCode];
  if (!rule) {
    return res.status(400).json({ error: '您输入的确认码有误，请重新输入！' });
  }

  if (isNoCookingToday) {
    // 10 “今日免做饭”模式
    if (confirmCode !== WIFE_CODE) {
      return res.status(403).json({ error: confirmCode === GUEST_CODE ? '您无权做此决定！' : '您输入的确认码有误，请重新输入！' });
    }
    // 11 构建邮件内容
    try {
      const mailParams = {
        Action: 'SingleSendMail',
        AccountName: 'ge@bluelu.cn',
        ReplyToAddress: 'false',
        AddressType: '1',
        ToAddress: '858568106@qq.com',
        Subject: `【好消息】${rule.subjectPrefix}通知：今日免做饭！`,
        TextBody: rule.bodyTemplateNoCooking(activities || [], note)
      };
      await client.request('SingleSendMail', mailParams, { method: 'POST' });
      res.json({ message: '邮件发送成功' });
    } catch (error) {
      console.error('邮件发送失败:', error);
      res.status(500).json({ error: '邮件发送失败' });
    }
  } else {
    // 正常点餐模式
    if (!selectedItems || selectedItems.length === 0) {
      return res.status(400).json({ error: '请至少选择一道菜！' });
    }
    try {
      const mealDateFormatted = mealDate.replace(/-/g, '年') + '日';
      const mealInfo = `${mealDateFormatted}-${mealTime}`;
      const itemList = selectedItems.map((item, index) => `${index + 1}、${item}`).join('\n');
      
      const mailParams = {
        Action: 'SingleSendMail',
        AccountName: 'ge@bluelu.cn',
        ReplyToAddress: 'false',
        AddressType: '1',
        ToAddress: '858568106@qq.com',
        Subject: `${mealInfo}${selectedItems.length}道菜品，${rule.subjectPrefix}已点餐！`,
        TextBody: rule.bodyTemplateNormal(
          selectedItems.length,
          mealInfo,
          itemList,
          note
        )
      };
      await client.request('SingleSendMail', mailParams, { method: 'POST' });
      res.json({ message: '邮件发送成功' });
    } catch (error) {
      console.error('邮件发送失败:', error);
      res.status(500).json({ error: '邮件发送失败' });
    }
  }
});

// 12. 配置静态文件服务
app.use(express.static(path.join(__dirname, '../diancan')));

// 13. 启动服务器
app.listen(3000, '0.0.0.0', () => {
  console.log('服务器运行在 http://0.0.0.0:3000');
  console.log('环境变量验证:');
  console.log('ACCESS_KEY_ID:', process.env.ACCESS_KEY_ID ? '已配置' : '未找到');
  console.log('ACCESS_KEY_SECRET:', process.env.ACCESS_KEY_SECRET ? '已配置' : '未找到');
  console.log('WIFE_CODE:', process.env.WIFE_CODE ? '已配置' : '未找到');
  console.log('GUEST_CODE:', process.env.GUEST_CODE ? '已配置' : '未找到');
});

// 14. 增强错误处理
process.on('unhandledRejection', (reason, promise) => {
  console.error('未处理的 Promise 拒绝:', reason.stack || reason);
});